@@ -1,4 +1,4 @@
-`BootAfterBootT.PI` <-
+BootAfterBootT.PI <-
 function(x,p,h,nboot,prob,correct)
 {
 set.seed(12345)
