@@ -1,4 +1,4 @@
-`OLS.ART` <-
+OLS.ART <-
 function(x,p,h,prob)
 {
     x <- as.matrix(x)
@@ -21,4 +21,3 @@ function(x,p,h,prob)
 return(list(coef=b,resid=e,forecast=f,PI=PImat))
 }
 
-
