@@ -1,4 +1,4 @@
-`Plot.Fore` <-
+Plot.Fore <-
 function(x,fore,start,end,frequency)
 {
 library(zoo)
@@ -12,5 +12,6 @@ fend <- m1[length(m1)]+h/frequency
 y2 <- zooreg(fore,fstart,fend,frequency)
 ts.plot(ts(y1,start,end,frequency),ts(y2,fstart,fend,frequency),lwd=c(1,2),col=c(1,4))
 abline(v=fstart,col=3,lwd=2)
+title(main="Time Plot and Point Forecasts",sub="blue = point forecasts", col.sub=4)
 }
 
